﻿using GarmentFactoryContracts.BusinessLogicsContracts;
using GarmentFactoryContracts.SearchModels;
using Microsoft.Extensions.Logging;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace GarmentFactoryView
{
    public partial class FormMakeDelivery : Form
    {
        private readonly ILogger _logger;

        private readonly ITextileLogic _logicTextile;

        private readonly IShopLogic _logicShop;
        public FormMakeDelivery(ILogger<FormMakeDelivery> logger, ITextileLogic logicTextile, IShopLogic logicShop)
        {
            InitializeComponent();
            _logger = logger;
            _logicTextile = logicTextile;
            _logicShop = logicShop;
        }

        private void ButtonSave_Click(object sender, EventArgs e)
        {
            if (comboBoxShop.SelectedValue == null)
            {
                MessageBox.Show("Выберите магазин", "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            if (comboBoxTextile.SelectedValue == null)
            {
                MessageBox.Show("Выберите продукт", "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            if (string.IsNullOrEmpty(textBoxCount.Text))
            {
                MessageBox.Show("Заполните поле Количество", "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            _logger.LogInformation("Shop replenishment");
            try
            {
                var textile = _logicTextile.ReadElement(new TextileSearchModel
                { Id = Convert.ToInt32(comboBoxTextile.SelectedValue) });
                if (textile == null)
                {
                    throw new Exception("Мороженое не найдено.");
                }
                var operationResult = _logicShop.MakeDelivery(new ShopSearchModel
                {
                    Id = Convert.ToInt32(comboBoxShop.SelectedValue)
                },
                textile,
                Convert.ToInt32(textBoxCount.Text));
                if (!operationResult)
                {
                    throw new Exception("Ошибка при проведении поставки.");
                }
                MessageBox.Show("Сохранение прошло успешно", "Сообщение", MessageBoxButtons.OK, MessageBoxIcon.Information);
                DialogResult = DialogResult.OK;
                Close();
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Shop replenishment error");
                MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            DialogResult = DialogResult.OK;
            Close();
        }

        private void ButtonCancel_Click(object sender, EventArgs e)
        {
            DialogResult = DialogResult.Cancel;
            Close();
        }

        private void FormMakeDelivery_Load(object sender, EventArgs e)
        {
            _logger.LogInformation("Textile loading");
            try
            {
                var list = _logicTextile.ReadList(null);
                if (list != null)
                {
                    comboBoxTextile.DisplayMember = "TextileName";
                    comboBoxTextile.ValueMember = "Id";
                    comboBoxTextile.DataSource = list;
                    comboBoxTextile.SelectedItem = null;
                }
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Textiles loading error");
                MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            _logger.LogInformation("Shops loading");
            try
            {
                var list = _logicShop.ReadList(null);
                if (list != null)
                {
                    comboBoxShop.DisplayMember = "ShopName";
                    comboBoxShop.ValueMember = "Id";
                    comboBoxShop.DataSource = list;
                    comboBoxShop.SelectedItem = null;
                }
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Shops loading error");
                MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
    }
}
